/**
 * $File: constants.rs $
 * $Date: 2021-10-17 19:51:21 $
 * $Revision: $
 * $Creator: Jen-Chieh Shen $
 * $Notice: See LICENSE.txt for modification and distribution information
 *                   Copyright © 2021 by Shen, Jen-Chieh $
 */
pub const SEPARATOR_FACTOR: f32 = 10.0;
pub const SEPARATOR_REDUCE: f32 = 0.5;
pub const CLASS_FACTOR: f32 = 10.0;
pub const FIRST_FACTOR: f32 = 3.0;
pub const CLASS_REDUCE: f32 = 0.5;

pub const DIST_WEIGHT: f32 = -10.0;
pub const HEAT_WEIGHT: f32 = 5.0;
pub const FACTOR_REDUCE: f32 = 0.02;

pub const MAX_LEN: usize = 80;
